"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.SyntaxHighlighter = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
let highlighterInstance = null;
async function getHighlighter() {
  if (!highlighterInstance) {
    highlighterInstance = await (0, _core.createHighlighterCore)({
      engine: (0, _engineJavascript.createJavaScriptRegexEngine)()
    });
  }
  return highlighterInstance;
}
const SyntaxHighlighter = ({
  text,
  language,
  theme,
  fontSize = 14,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [tokens, setTokens] = _react.default.useState([]);
  const [loading, setLoading] = _react.default.useState(true);
  const [error, setError] = _react.default.useState(null);

  // Normalize theme
  const normalizedTheme = (0, _react.useMemo)(() => {
    console.log('Raw theme:', theme);
    const normalized = (0, _core.normalizeTheme)(theme);
    console.log('Normalized theme:', normalized);
    return normalized;
  }, [theme]);

  // Inside the SyntaxHighlighter effect
  _react.default.useEffect(() => {
    const highlight = async () => {
      try {
        setLoading(true);
        const highlighter = await getHighlighter();

        // Debug theme object
        console.log('Theme detail:', {
          name: theme.name,
          type: theme.type,
          colors: Boolean(theme.colors),
          tokenColors: Boolean(theme.tokenColors),
          settings: theme.settings?.length,
          themeJSON: JSON.stringify(theme, null, 2)
        });

        // Load language and theme if needed
        if (typeof language !== 'string') {
          await highlighter.loadLanguage(language);
        }
        await highlighter.loadTheme(theme);

        // Log the grammar info
        console.log('Grammar info:', {
          name: typeof language === 'string' ? language : language.name,
          scopes: highlighter.getLoadedLanguages()
        });

        // Highlight the code with explicit options
        const result = highlighter.codeToTokens(text, {
          lang: typeof language === 'string' ? language : language.name,
          theme,
          includeExplanation: true
        });

        // Log the token scopes
        console.log('First token:', result.tokens[0]?.map(token => ({
          content: token.content,
          color: token.color,
          scopes: token.explanation?.[0]?.scopes.map(s => s.scopeName),
          themeMatches: token.explanation?.[0]?.scopes[0]?.themeMatches
        })));
        setTokens(result.tokens);
        setError(null);
      } catch (err) {
        setError(err instanceof Error ? err.message : 'Failed to highlight code');
        console.error('Highlighting error:', err);
      } finally {
        setLoading(false);
      }
    };
    highlight();
  }, [text, language, theme]);
  const renderToken = (token, index) => {
    const styles = [{
      fontSize
    }];
    if (textStyle) {
      styles.push(textStyle);
    }

    // Add color from token
    if (token.color) {
      styles.push({
        color: token.color
      });
    }

    // Add font styles
    if (token.fontStyle === 1) styles.push({
      fontStyle: 'italic'
    });
    if (token.fontStyle === 2) styles.push({
      fontWeight: 'bold'
    });
    if (token.fontStyle === 4) styles.push({
      textDecorationLine: 'underline'
    });

    // If token has no color, use theme's foreground color
    if (!token.color && normalizedTheme.fg) {
      styles.push({
        color: normalizedTheme.fg
      });
    }
    const finalStyle = _reactNative.StyleSheet.flatten(styles);
    console.log('Token style:', {
      content: token.content,
      color: token.color || normalizedTheme.fg,
      styles: finalStyle
    });
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: finalStyle,
      children: token.content
    }, `${token.offset}-${index}`);
  };
  const renderLine = (lineTokens, index) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    children: lineTokens.map((token, tokenIndex) => renderToken(token, tokenIndex))
  }, index);
  if (loading) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [{
        backgroundColor: normalizedTheme.bg,
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ActivityIndicator, {})
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [{
        backgroundColor: normalizedTheme.bg,
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
        style: {
          color: '#ff6b6b'
        },
        children: ["Error:", error]
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    style: [{
      backgroundColor: normalizedTheme.bg
    }, scrollViewProps?.style],
    contentContainerStyle: [containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((lineTokens, index) => renderLine(lineTokens, index))
    })
  });
};
exports.SyntaxHighlighter = SyntaxHighlighter;
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map